@@ -4,34 +4,28 @@ import random
 from .reddit import Reddit
 import datetime
 import requests.auth
-from dotenv import load_dotenv
-import os
-
-load_dotenv(".env")
-client_id = os.getenv("CLIENT_ID")
-client_secret = os.getenv("CLIENT_SECRET")
-auth = os.getenv("AUTH")
-user_agent = os.getenv("USER_AGENT")
-
-client_auth = requests.auth.HTTPBasicAuth(client_id, client_secret)
-headers = {"Authorization": auth, "User-Agent": user_agent}
 
 
 class User:
-    def __init__(self, user):
+    def __init__(self, user_agent, user, client_id, client_secret):
         self.user = user
+        self.user_agent = user_agent
+        self.client_id = client_id
+        self.client_secret = client_secret
 
     def get_post(self):
         """
         :return: (str) Info about the randomly selected post from the user
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/hot.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -71,12 +65,14 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media == "null":
-                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            if not media:
+                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+                if contenttext == "":
+                    contenttext = contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
                 contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
-                contenttext = meme["data"]["children"][randompost]["data"]["url"]
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
 
             return Reddit(
                 content=contenttext,
@@ -102,7 +98,7 @@ class User:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -142,8 +138,8 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media == "null":
-                contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            if not media:
+                contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
             elif media:
                 contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
@@ -175,12 +171,14 @@ class User:
          of all time)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/top.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -251,7 +249,7 @@ class User:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -323,12 +321,14 @@ class User:
         :return: (str) Info about the randomly selected post (new)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/new.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -399,7 +399,7 @@ class User:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -471,13 +471,15 @@ class User:
         :return: (str) Info about the randomly selected post (new)
         """
 
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        headers = {"User-Agent": self.user_agent}
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/controversial.json",
                                    headers=headers, auth=client_auth)
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
@@ -549,7 +551,7 @@ class User:
             meme = json.loads(request.content)
 
             try:
-                randompost = random.randint(0, meme["data"]["dist"])
+                randompost = random.randint(0, meme["data"]["dist"] - 1)
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
